Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(354)

Unified Diff: content/public/common/resource_response_info.h

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: rebase Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/common/resource_response_info.h
diff --git a/content/public/common/resource_response_info.h b/content/public/common/resource_response_info.h
index ca38798f1fa903e76f10b4f749850a23aa311fa0..e99510dda10d4700aa6b9aac53c56fc5a2c6a091 100644
--- a/content/public/common/resource_response_info.h
+++ b/content/public/common/resource_response_info.h
@@ -13,6 +13,7 @@
#include "base/memory/ref_counted.h"
#include "base/time/time.h"
#include "content/common/content_export.h"
+#include "content/public/common/previews_state.h"
#include "content/public/common/resource_devtools_info.h"
#include "net/base/host_port_pair.h"
#include "net/base/load_timing_info.h"
@@ -141,8 +142,8 @@ struct CONTENT_EXPORT ResourceResponseInfo {
// the ServiceWorker. Empty if the response isn't from the CacheStorage.
std::string cache_storage_cache_name;
- // Whether or not the request was for a LoFi version of the resource.
- bool is_using_lofi;
+ // Which Previews version of the resource the request was for.
+ PreviewsState previews_state;
// Effective connection type when the resource was fetched. This is populated
// only for responses that correspond to main frame requests.

Powered by Google App Engine
This is Rietveld 408576698